@@ -223,7 +223,18 @@ class ApiGatewayToIot(
         :summary: Constructs a new instance of the ApiGatewayIot class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToIot.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                iot_endpoint: builtins.str,
+                api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
+                api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToIotProps(
@@ -291,7 +302,16 @@ class ApiGatewayToIotProps:
         if isinstance(log_group_props, dict):
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if __debug__:
-            type_hints = typing.get_type_hints(ApiGatewayToIotProps.__init__)
+            def stub(
+                *,
+                iot_endpoint: builtins.str,
+                api_gateway_create_api_key: typing.Optional[builtins.bool] = None,
+                api_gateway_execution_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                api_gateway_props: typing.Optional[typing.Union[aws_cdk.aws_apigateway.RestApiProps, typing.Dict[str, typing.Any]]] = None,
+                log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument iot_endpoint", value=iot_endpoint, expected_type=type_hints["iot_endpoint"])
             check_type(argname="argument api_gateway_create_api_key", value=api_gateway_create_api_key, expected_type=type_hints["api_gateway_create_api_key"])
             check_type(argname="argument api_gateway_execution_role", value=api_gateway_execution_role, expected_type=type_hints["api_gateway_execution_role"])
